@@ -1,3 +1,17 @@
+#                       Copyright 2020 Saad Mairaj
+# 
+#    Licensed under the Apache License, Version 2.0 (the "License");
+#    you may not use this file except in compliance with the License.
+#    You may obtain a copy of the License at
+# 
+#        http://www.apache.org/licenses/LICENSE-2.0
+# 
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS,
+#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#    See the License for the specific language governing permissions and
+#    limitations under the License.
+
 from tkinter import ttk
 import tkinter as _TK
 import re
@@ -273,7 +287,10 @@ class Widget(_Canvas):
         self.tag_raise('_bit')
         self.tag_raise('_tf')
         self.after(50, self._getconfigure2)
-        self.master.focus()
+        # self.master.focus()
+        ## NEED TESTS:- 
+        ## if this is really needed, then change master with root 
+        ## window as this set focus to entry widget if the master is in an entry widget.
 
     def on_press(self, *ags):
         ''' Internal function. When button is pressed <Button-1>'''
